# Generated by roxygen2: do not edit by hand

S3method(print,CohortContrastObject)
export(CohortContrast)
export(automaticCorrelationCombineConcepts)
export(automaticHierarchyCombineConcepts)
export(checkDataMode)
export(checkPythonDeps)
export(cohortFromCSV)
export(cohortFromCohortTable)
export(cohortFromDataTable)
export(cohortFromJSON)
export(configurePython)
export(createControlCohortInverse)
export(createControlCohortMatching)
export(generateMappingTable)
export(getPythonInfo)
export(getTopSeparatingConcepts)
export(installPythonDeps)
export(installPythonDepsOffline)
export(loadCohortContrastStudy)
export(matchCohortsByAge)
export(nGramClusterSummarization)
export(nGramDiscovery)
export(precomputeSummary)
export(removeTemporalBias)
export(resolveCohortTableOverlaps)
export(runCohortContrastViewer)
export(stopCohortContrastViewer)
importFrom(data.table,":=")
importFrom(data.table,fread)
importFrom(dplyr,"%>%")
importFrom(foreach,"%dopar%")
