## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----include = TRUE, eval=FALSE, echo=TRUE------------------------------------
# configurePython(
#   pythonPath = "/usr/bin/python3",
#   virtualenvName = "r-cohortcontrast-viewer",
#   createVenv = TRUE
# )

## ----include = TRUE, eval=FALSE, echo=TRUE------------------------------------
# configurePython(
#   pythonPath = "/usr/bin/python3",
#   createVenv = FALSE
# )

## ----include = TRUE, eval=FALSE, echo=TRUE------------------------------------
# installPythonDeps()

## ----include = TRUE, eval=FALSE, echo=TRUE------------------------------------
# installPythonDepsOffline(
#   packagesDir = "/opt/cohortcontrast/packages",
#   platform = "linux_x86_64"
# )

## ----include = TRUE, eval=FALSE, echo=TRUE------------------------------------
# checkPythonDeps()

## ----include = TRUE, eval=FALSE, echo=TRUE------------------------------------
# summaryResult <- precomputeSummary(
#   studyPath = "/data/studies/LungCancer_1Y",
#   outputPath = "/data/studies/LungCancer_1Y_summary",
#   clusterKValues = c(2, 3, 4, 5),
#   minibatchKMeansCutoffPatients = 50000
# )

## ----include = TRUE, eval=FALSE, echo=TRUE------------------------------------
# runCohortContrastViewer(
#   dataDir = "/data/studies",
#   host = "0.0.0.0",
#   port = 8050,
#   mode = "server",
#   logFile = "/data/studies/contrast_viewer.log",
#   openBrowser = FALSE,
#   background = TRUE
# )

## ----include = TRUE, eval=FALSE, echo=TRUE------------------------------------
# runCohortContrastViewer(
#   dataDir = "/data/studies",
#   mode = "server",
#   allowExports = FALSE,
#   openBrowser = FALSE
# )

