## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----include = TRUE, eval=FALSE, echo=TRUE------------------------------------
# exampleDataDir <- system.file("example", "st", package = "CohortContrast", mustWork = TRUE)
# 
# CohortContrast::runCohortContrastViewer(
#   dataDir = exampleDataDir
# )

## -----------------------------------------------------------------------------
patientStudyPath <- system.file("example", "st", "lc500", package = "CohortContrast")
summaryStudyPath <- system.file("example", "st", "lc500s", package = "CohortContrast")

# Check which mode the Viewer would detect for each bundled study.
data.frame(
  study = c("lc500", "lc500s"),
  mode = c(
    CohortContrast::checkDataMode(patientStudyPath)$mode,
    CohortContrast::checkDataMode(summaryStudyPath)$mode
  )
)

