## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## -----------------------------------------------------------------------------
if (requireNamespace("nanoparquet", quietly = TRUE)) {
  studyDir <- system.file("example", "st", package = "CohortContrast")
  study <- CohortContrast::loadCohortContrastStudy("lc500", pathToResults = studyDir)

  # Order concepts by target prevalence to mimic a common Dashboard review step.
  dashboardPreview <- study$data_features[
    order(study$data_features$TARGET_SUBJECT_PREVALENCE, decreasing = TRUE),
    c("CONCEPT_ID", "CONCEPT_NAME", "HERITAGE", "TARGET_SUBJECT_PREVALENCE")
  ]

  utils::head(dashboardPreview, 5)
}

